'use strict'

import axios from 'axios'
import { Message } from 'element-ui'

const config = {
  baseURL: 'http://192.168.178.41:8011/',
  timeout: 60 * 1000 // Timeout
}
const _axios = axios.create(config)

// 随机数生成
function getRandomSixNum () {
  let RandomSixStr = ''
  for (let i = 0; i < 6; i++) {
    RandomSixStr += String(Math.floor(Math.random() * 10))
  }
  return RandomSixStr
}
_axios.interceptors.request.use(
  function (config) {
    config.data = {
      timestamp: String(Date.now()), // 时间戳，毫秒级,13位
      once: getRandomSixNum() + Date.now() + Date.now(), // 唯一编号，保证每次请求唯一,32位
      version: 'V1.0.0', // 版本号，V1.0.0
      graph: 'line2', // 图谱
      operator: '', // 操作员
      data: config.data // 请求业务数据
    }
    return config
  },
  function (error) {
    // Do something with request error
    return Promise.reject(error)
  }
)

// 设置cookie
export function setCookie (name, value, day) {
  const date = new Date()
  date.setDate(date.getDate() + day)
  document.cookie = `${name}=${value};expires=${date}`
}

// 获取cookie
export function getCookie (name) {
  const reg = RegExp(`${name}=([^;]+)`)
  const arr = document.cookie.match(reg)
  if (arr) {
    return arr[1]
  }
  return ''
}

// Add a response interceptor
_axios.interceptors.response.use(
  function (response) {
    if (response.headers.authorization) setCookie('authorization', response.headers.authorization) // 保存帐号到cookie
    const { data: result } = response
    const { data, code, subMsg } = result
    if (+code === 0) {
      return data
    } else {
      Message.error(subMsg)
      return Promise.reject(subMsg)
    }
  },
  function (error) {
    Message.error('服务端异常，请稍候再试')
    return Promise.reject(error)
  }
)

export default _axios
